![Tests](https://github.com/RadostW/saxs_single_bead/actions/workflows/tests.yml/badge.svg)

# saxs_single_bead

All Python package to compute small angle X-ray scattering (SAXS) profiles in one-bead-per-residue approximation with numpy

# Algorithm concept

D. Tong, S. Yang and L. Lu  *Accurate optimization of amino acid form factors for computing small-angle X-ray scattering intensity of atomistic protein structures*; J. Appl. Cryst. (2016)

Accurate optimization of amino acid form factors for computing small-angle X-ray scattering intensity of atomistic protein structures

# License

This software is licensed under MIT license

Copyright (c) Radost Waszkiewicz (2022)
